# Generated by Django 3.2.9 on 2022-01-20 19:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0008_rename_swap_html_authtoggle_faravahar'),
    ]

    operations = [
        migrations.AddField(
            model_name='authtoggle',
            name='email',
            field=models.EmailField(default='', max_length=50),
        ),
    ]
