# Generated by Django 3.2.4 on 2021-12-02 10:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0007_rename_protected_authtoggle_is_protected'),
    ]

    operations = [
        migrations.RenameField(
            model_name='authtoggle',
            old_name='swap_html',
            new_name='faravahar',
        ),
    ]
