<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="robots" content="noindex,nofollow" />
    <title>Logged Out Page</title>
    <style>
        h2 {
            text-align: center;
        }
        #spacer {
            height: 15%;
        }
        p {
            text-align: center;
        }
    </style>
</head>

<body>
    <div id="spacer">
    </div>
    <p>You have been logged out!</p>
    <h2><a href="{% url 'index' %}">Click Here to Login Again.</a></h2>

</body>
</html>