# Generated by Django 3.2.4 on 2021-09-27 18:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0002_auto_20210529_2306'),
    ]

    operations = [
        migrations.AddField(
            model_name='authtoggle',
            name='timeout',
            field=models.IntegerField(default=15),
        ),
    ]
