# Generated by Django 3.2.4 on 2021-10-24 18:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0004_alter_authtoggle_timeout'),
    ]

    operations = [
        migrations.RenameField(
            model_name='authtoggle',
            old_name='enable_protection',
            new_name='On',
        ),
    ]
