::selection {
  background-color: crimson;
}

label {
    color: crimson;
    font-weight: bold;
    font-size: 20px;
}

 body {
    background: black;
  color: white;
  text-align: center;
  margin: 0 auto;
}

img {
  border-radius: 25px;
  margin-top: 100px;
  /*border: dashed;*/
}

h3 {
  margin-bottom: 36px;
}

/* MODIFIED: Target only submit inputs to avoid affecting the password toggle icon */
input[type="submit"] {
  margin:10px;
  border-radius: 14px;
  margin-top: 20px;
  padding: 15px;
  margin-left: 30px;
  font-size:75%;
}

h1{
  font-size: 2em;
  /* margin-top:75px;*/
}

hr {
  margin-top: 40px;
  width: 40%;
  margin-bottom: 40px;
}


/* section {
  margin: 0 1px;
}*/

/*
.card {
    border: none;
}
.btn-secondary {
  background-color: crimson;
  border-color: black;
}
*/
/* unvisited link */
a:link {
color: crimson;
text-shadow: 0 0 5px #fff, 0 0 10px #fff, 0 0 30px #fff, 0 0 20px white;
}
/* visited link */
a:visited {
color: crimson;
}

/* mouse over link */
a:hover {
color: crimson;
}

/* selected link */
a:active {
color: crimson;
}
/* #id {
  overflow: hidden;
}*/

.container {
  background-color: crimson;
  padding: 15px;
  animation: cssAnimation 1s ease-in 2s forwards;
}
/* Useless Css */
/* div {
  display: block;
} */
@keyframes cssAnimation {
  to {
    transform: scale(10) translateY(-50%);
    opacity: 0;
  }
}

#muerte {
 display: block;
 max-width: 80%;
 margin: auto;
 margin-top: 150px;
}

#passphrase {
  display: block;
  color: crimson;
  
}

.submit {
  padding: 10px;
  padding-left: 20px;
  padding-right: 20px;
}